# 0.1.5

- Replace `Poetry` with `uv` for dependency management
- Replace some other development tools
- Set geoip2 dependency error to warning

# 0.1.4

- Fixed error when local variable 'device' is not associated with a value

# 0.1.3

- Fixed `SessionMiddleware` import in `middleware`

# 0.1.2

- Initial release
